You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cassandra.apache.org by br...@apache.org on 2013/11/22 20:24:48 UTC

[2/6] git commit: Change removetoken refs to removenode

Change removetoken refs to removenode


Project: http://git-wip-us.apache.org/repos/asf/cassandra/repo
Commit: http://git-wip-us.apache.org/repos/asf/cassandra/commit/da5ff080
Tree: http://git-wip-us.apache.org/repos/asf/cassandra/tree/da5ff080
Diff: http://git-wip-us.apache.org/repos/asf/cassandra/diff/da5ff080

Branch: refs/heads/cassandra-2.0
Commit: da5ff08055086979ed01c34154670799c87f08c4
Parents: 85668c5
Author: Brandon Williams <br...@apache.org>
Authored: Fri Nov 22 13:22:45 2013 -0600
Committer: Brandon Williams <br...@apache.org>
Committed: Fri Nov 22 13:22:45 2013 -0600

----------------------------------------------------------------------
 src/java/org/apache/cassandra/dht/BootStrapper.java     |  2 +-
 src/java/org/apache/cassandra/gms/Gossiper.java         |  2 +-
 .../org/apache/cassandra/service/StorageService.java    | 12 ++++++------
 3 files changed, 8 insertions(+), 8 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cassandra/blob/da5ff080/src/java/org/apache/cassandra/dht/BootStrapper.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/dht/BootStrapper.java b/src/java/org/apache/cassandra/dht/BootStrapper.java
index ff76534..da91be7 100644
--- a/src/java/org/apache/cassandra/dht/BootStrapper.java
+++ b/src/java/org/apache/cassandra/dht/BootStrapper.java
@@ -102,7 +102,7 @@ public class BootStrapper
             {
                 Token token = StorageService.getPartitioner().getTokenFactory().fromString(tokenString);
                 if (metadata.getEndpoint(token) != null)
-                    throw new ConfigurationException("Bootstraping to existing token " + tokenString + " is not allowed (decommission/removetoken the old node first).");
+                    throw new ConfigurationException("Bootstraping to existing token " + tokenString + " is not allowed (decommission/removenode the old node first).");
                 tokens.add(token);
             }
             return tokens;

http://git-wip-us.apache.org/repos/asf/cassandra/blob/da5ff080/src/java/org/apache/cassandra/gms/Gossiper.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/gms/Gossiper.java b/src/java/org/apache/cassandra/gms/Gossiper.java
index 545d26b..cec9a7a 100644
--- a/src/java/org/apache/cassandra/gms/Gossiper.java
+++ b/src/java/org/apache/cassandra/gms/Gossiper.java
@@ -384,7 +384,7 @@ public class Gossiper implements IFailureDetectionEventListener, GossiperMBean
 
     /**
      * This method will begin removing an existing endpoint from the cluster by spoofing its state
-     * This should never be called unless this coordinator has had 'removetoken' invoked
+     * This should never be called unless this coordinator has had 'removenode' invoked
      *
      * @param endpoint - the endpoint being removed
      * @param hostId - the ID of the host being removed

http://git-wip-us.apache.org/repos/asf/cassandra/blob/da5ff080/src/java/org/apache/cassandra/service/StorageService.java
----------------------------------------------------------------------
diff --git a/src/java/org/apache/cassandra/service/StorageService.java b/src/java/org/apache/cassandra/service/StorageService.java
index cd98689..250fa62 100644
--- a/src/java/org/apache/cassandra/service/StorageService.java
+++ b/src/java/org/apache/cassandra/service/StorageService.java
@@ -1238,7 +1238,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
      *   set if the node is dead and has been removed by its REMOVAL_COORDINATOR
      *
      * Note: Any time a node state changes from STATUS_NORMAL, it will not be visible to new nodes. So it follows that
      * you should never bootstrap a new node during a removetoken, decommission or move.
      */
     public void onChange(InetAddress endpoint, ApplicationState state, VersionedValue value)
     {
@@ -1590,7 +1590,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
     }
 
     /**
      * Handle notification that a node being actively removed from the ring via 'removetoken'
      *
      * @param endpoint node
      * @param pieces either REMOVED_TOKEN (node is gone) or REMOVING_TOKEN (replicas need to be restored)
@@ -1601,7 +1601,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
 
         if (endpoint.equals(FBUtilities.getBroadcastAddress()))
         {
-            logger.info("Received removeToken gossip about myself. Is this node rejoining after an explicit removetoken?");
+            logger.info("Received removenode gossip about myself. Is this node rejoining after an explicit removenode?");
             try
             {
                 drain();
@@ -1842,7 +1842,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
 
         TokenMetadata temp = tokenMetadata.cloneAfterAllLeft();
 
         // endpoint might or might not be 'leaving'. If it was not leaving (that is, removetoken
         // command was used), it is still present in temp and must be removed.
         if (temp.isMember(endpoint))
             temp.removeEndpoint(endpoint);
@@ -3137,7 +3137,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
         }
         else
         {
-            throw new UnsupportedOperationException("No tokens to force removal on, call 'removetoken' first");
+            throw new UnsupportedOperationException("No tokens to force removal on, call 'removenode' first");
         }
     }
 
@@ -3173,7 +3173,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
             logger.warn("Node " + endpoint + " is already being removed, continuing removal anyway");
 
         if (!replicatingNodes.isEmpty())
-            throw new UnsupportedOperationException("This node is already processing a removal. Wait for it to complete, or use 'removetoken force' if this has failed.");
+            throw new UnsupportedOperationException("This node is already processing a removal. Wait for it to complete, or use 'removenode force' if this has failed.");
 
         // Find the endpoints that are going to become responsible for data
         for (String table : Schema.instance.getNonSystemTables())
@@ -1238,7 +1238,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
      *
      * Note: Any time a node state changes from STATUS_NORMAL, it will not be visible to new nodes. So it follows that
-     * you should never bootstrap a new node during a removetoken, decommission or move.
+     * you should never bootstrap a new node during a removenode, decommission or move.
      */
     public void onChange(InetAddress endpoint, ApplicationState state, VersionedValue value)
@@ -1590,7 +1590,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
 
     /**
-     * Handle notification that a node being actively removed from the ring via 'removetoken'
+     * Handle notification that a node being actively removed from the ring via 'removenode'
      *
      * @param endpoint node
@@ -1842,7 +1842,7 @@ public class StorageService extends NotificationBroadcasterSupport implements IE
         TokenMetadata temp = tokenMetadata.cloneAfterAllLeft();
 
-        // endpoint might or might not be 'leaving'. If it was not leaving (that is, removetoken
+        // endpoint might or might not be 'leaving'. If it was not leaving (that is, removenode
         // command was used), it is still present in temp and must be removed.
         if (temp.isMember(endpoint))